Executes a query on a Daf object and returns the result. Queries provide a way to extract, filter, and manipulate data from a Daf object using a composable syntax. Queries can retrieve scalars, vectors, matrices, or sets of names depending on the operations used.
Value
The result of the query, which could be a scalar, vector, matrix, or set of names depending on the query
Details
See the Julia documentation for details.
See also
has_query(), parse_query(), get_dataframe_query(), and the query operations documentation.
Examples
if (FALSE) { # \dontrun{
setup_daf()
daf <- memory_daf("example")
add_axis(daf, "cell", c("A", "B", "C"))
set_vector(daf, "cell", "score", c(1.0, 2.0, 3.0))
get_query(daf, Axis("cell") |> LookupVector("score"))
} # }