Retrieves the value of a scalar property with the given name from the Daf data set.
Details
Numeric scalars are returned as integers or doubles, regardless of the specific data type they are stored as in the Daf data set. See the Julia documentation for details.
Examples
if (FALSE) { # \dontrun{
setup_daf()
daf <- memory_daf("example")
set_scalar(daf, "version", "1.0")
get_scalar(daf, "version") # "1.0"
} # }