Determines whether a scalar property with the specified name exists in the Daf data set.
Details
Scalar properties are global values associated with the entire Daf data set. See the Julia documentation for details.
Examples
if (FALSE) { # \dontrun{
setup_daf()
daf <- memory_daf("example")
set_scalar(daf, "version", "1.0")
has_scalar(daf, "version") # TRUE
} # }