Determines whether an axis with the specified name exists in the Daf data set.
Details
Axes are fundamental dimensions in a Daf data set along which vector and matrix data are stored. Each axis has a collection of unique named entries. See the Julia documentation for details.
Examples
if (FALSE) { # \dontrun{
setup_daf()
daf <- memory_daf("example")
add_axis(daf, "cell", c("A", "B", "C"))
has_axis(daf, "cell") # TRUE
has_axis(daf, "gene") # FALSE
} # }