Determines whether a vector property with the specified name exists for the given axis.
Details
Vector properties store one-dimensional data along a specific axis. Each entry in the axis has a corresponding value in the vector. See the Julia documentation for details.
Examples
if (FALSE) { # \dontrun{
setup_daf()
daf <- memory_daf("example")
add_axis(daf, "cell", c("A", "B", "C"))
set_vector(daf, "cell", "type", c("T1", "T2", "T1"))
has_vector(daf, "cell", "type") # TRUE
} # }